import MeleeWeapon from 'melee/melee-weapon';
export default class Ripper extends MeleeWeapon {
    constructor() {
        super(...arguments);
        this.itemTypeId = 'weapon:ripper';
        // MAIN MELEE PROPERTIES
        this.name = 'Ripper';
        this.drawTime = 1050; // in ms
        this.displayDrawCooldown = true;
        this.leftAttack = {
            enabled: true,
            damages: 60,
            delay: 2,
            cooldown: 0,
            displayCooldown: true,
            range: 6,
            precision: 0.07,
            sideAttack: {
                timeToSlash: 150, // in ms
                rayPerLine: 15,
                borderRadius: 0, // in percent
                lineCount: 1,
                areaHeight: 2.3, // in blocks
                areaWeight: {
                    from: -30, // in degree
                    to: 30, // in degree
                },
            },
            sounds: {
                onHitBlock: {
                    soundIds: ['cso.combatknife.wall'],
                    pitch: 1,
                    volume: 1.5,
                },
                onHitEntity: {
                    soundIds: ['cso.tomahawk.hit'],
                    pitch: 1,
                    volume: 1.5,
                },
                onMiss: {
                    soundIds: [''],
                    pitch: 0.5,
                    volume: 100,
                },
            },
            particles: {
                onHitBlock: {
                    particleIds: ['move:tiger', 'hit:bullet5', 'move:tiger', 'move:tiger', 'move:tiger'],
                },
                onHitEntity: {
                    particleIds: ['ag:blood', 'ag:blood', 'ag:blood', 'knife:sweep'],
                },
            },
        };
        this.rightAttack = {
            enabled: true,
            damages: -1,
            delay: 0,
            fire: {
                time : 1000, // in ms,
                useEffects : true
            },
            cooldown: 0,
            range: 0.3,
            displayCooldown: true,
            precision: 0.07,
            sounds: {
                onHitBlock: {
                    soundIds: [''],
                    pitch: 1,
                    volume: 1.5,
                },
                onHitEntity: {
                    soundIds: [''],
                    pitch: 1,
                    volume: 1.5,
                },
                onMiss: {
                    soundIds: [''],
                    pitch: 0.5,
                    volume: 100,
                },
            },
            particles: {
                onHitBlock: {
                    particleIds: ['move:tiger', 'hit:bullet5', 'move:tiger', 'move:tiger', 'move:tiger'],
                },
                onHitEntity: {
                    particleIds: ['ag:blood', 'ag:blood', 'ag:blood', 'knife:sweep'],
                },
            },
        };
        // ATTACK on draw
        this.initialAttack = {
            enabled: false,
        };
        // Charge System
        this.charges = {
            enabled: true,
            timePerSquare: [55],
            functionsTriggeredPerSquare: [],
            functionsTriggeredAtReleasedPerSquare: [],
            damagePerSquare: [1.5],
            displaySquares: false,
            triggerAttackIfLastSquareIsReached: true,
        };
        this.chargeAttack = {
            enabled: true,
            damages: -1,
            delay: 0,
            cooldown: 0,
            range: 6,
            knockback: {
                Ximpusle: -1.0,
                Zimpusle: -1.0,
            },
            precision: 0.07,
            sounds: {
                onHitBlock: {
                    soundIds: ['cso.combatknife.wall'],
                    pitch: 1,
                    volume: 3,
                },
                onHitEntity: {
                    soundIds: ['cso.tomahawk.hit'],
                    pitch: 1,
                    volume: 3,
                },
            },
            particles: {
                onHitBlock: {
                    particleIds: ['move:tiger', 'hit:bullet5', 'move:tiger', 'move:tiger', 'move:tiger'],
                },
                onHitEntity: {
                    particleIds: ['ag:blood', 'ag:blood', 'ag:blood', 'knife:sweep'],
                },
            },
        };
        this.sounds = {
            onDraw: {
                soundIds: [''],
                pitch: 1,
                volume: 0.2,
            },
        };
        this.particles = {
            onDraw: {
                particleIds: [''],
            },
        };
    }
}
